pub fn static_router(files: StaticFiles) -> RouterExpand description
Build a router that serves every path under the given prefix from
files.root. Mount with .nest("/static", static_router(...)).
pub fn static_router(files: StaticFiles) -> RouterBuild a router that serves every path under the given prefix from
files.root. Mount with .nest("/static", static_router(...)).